summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Boles <dboles.src@gmail.com>2018-05-26 01:06:00 +0100
committerDaniel Boles <dboles.src@gmail.com>2018-05-26 01:06:00 +0100
commite7809f43ecd07b2aa0a140129ddc6129bf23f266 (patch)
treeab63190dbb7e71e49a7096899aa136bd88eab201
parent4bb3ac3e814e3808a0525219c89531fac370e640 (diff)
downloadgtk+-e7809f43ecd07b2aa0a140129ddc6129bf23f266.tar.gz
SpinButton: Fix an obviously wrong arg description
:climb-rate is not about what you get when you single-click on a button, as this implied: it's what happens if you hold down a button or a key. Fix the description of @climb_rate to new(), and while here, mention the key in the blurb of :climb-rate itself.
-rw-r--r--gtk/gtkspinbutton.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/gtkspinbutton.c b/gtk/gtkspinbutton.c
index 7b5cd7c5ca..6a88e40a7d 100644
--- a/gtk/gtkspinbutton.c
+++ b/gtk/gtkspinbutton.c
@@ -338,7 +338,7 @@ gtk_spin_button_class_init (GtkSpinButtonClass *class)
PROP_CLIMB_RATE,
g_param_spec_double ("climb-rate",
P_("Climb Rate"),
- P_("The acceleration rate when you hold down a button"),
+ P_("The acceleration rate when you hold down a button or key"),
0.0, G_MAXDOUBLE, 0.0,
GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
@@ -1594,8 +1594,8 @@ gtk_spin_button_configure (GtkSpinButton *spin_button,
* gtk_spin_button_new:
* @adjustment: (allow-none): the #GtkAdjustment object that this spin
* button should use, or %NULL
* @climb_rate: specifies how much the spin button changes when an arrow
* is clicked on
* @digits: the number of decimal places to display
*
* Creates a new #GtkSpinButton.
@@ -1594,8 +1594,8 @@ gtk_spin_button_configure (GtkSpinButton *spin_button,
* @adjustment: (allow-none): the #GtkAdjustment object that this spin
* button should use, or %NULL
- * @climb_rate: specifies how much the spin button changes when an arrow
- * is clicked on
+ * @climb_rate: specifies by how much the rate of change in the value will
+ * accelerate if you continue to hold down an up/down button or arrow key
* @digits: the number of decimal places to display
*